@@ -29,9 +29,6 @@ LOG = logging.getLogger(__name__)
 
 class UpdateVPNService(forms.SelfHandlingForm):
     name = forms.CharField(max_length=80, label=_("Name"), required=False)
-    vpnservice_id = forms.CharField(
-        label=_("ID"),
-        widget=forms.TextInput(attrs={'readonly': 'readonly'}))
     description = forms.CharField(
         required=False, max_length=80, label=_("Description"))
     admin_state_up = forms.BooleanField(label=_("Enable Admin State"),
@@ -46,15 +43,15 @@ class UpdateVPNService(forms.SelfHandlingForm):
                                    'admin_state_up': context['admin_state_up'],
                                    }}
             vpnservice = api_vpn.vpnservice_update(
-                request, context['vpnservice_id'], **data)
-            msg = (_('VPN Service %s was successfully updated.')
+                request, self.initial['vpnservice_id'], **data)
+            msg = (_('VPN service %s was successfully updated.')
                    % context['name'])
             messages.success(request, msg)
             return vpnservice
         except Exception as e:
-            LOG.info('Failed to update VPN Service %(id)s: %(exc)s',
-                     {'id': context['vpnservice_id'], 'exc': e})
-            msg = _('Failed to update VPN Service %s') % context['name']
+            LOG.info('Failed to update VPN service %(id)s: %(exc)s',
+                     {'id': self.initial['vpnservice_id'], 'exc': e})
+            msg = _('Failed to update VPN service %s') % context['name']
             redirect = reverse(self.failure_url)
             exceptions.handle(request, msg, redirect=redirect)
 
@@ -64,9 +61,6 @@ class UpdateEndpointGroup(forms.SelfHandlingForm):
         max_length=80,
         label=_("Name"),
         required=False)
-    endpoint_group_id = forms.CharField(
-        label=_("ID"),
-        widget=forms.TextInput(attrs={'readonly': 'readonly'}))
     description = forms.CharField(
         required=False,
         max_length=80,
@@ -81,14 +75,14 @@ class UpdateEndpointGroup(forms.SelfHandlingForm):
                      'description': context['description']}
                     }
             endpointgroup = api_vpn.endpointgroup_update(
-                request, context['endpoint_group_id'], **data)
+                request, self.initial['endpoint_group_id'], **data)
             msg = (_('Endpoint Group %s was successfully updated.')
                    % context['name'])
             messages.success(request, msg)
             return endpointgroup
         except Exception as e:
             LOG.info('Failed to update Endpint Group %(id)s: %(exc)s',
-                     {'id': context['endpoint_group_id'], 'exc': e})
+                     {'id': self.initial['endpoint_group_id'], 'exc': e})
             msg = _('Failed to update Endpint Group %s') % context['name']
             redirect = reverse(self.failure_url)
             exceptions.handle(request, msg, redirect=redirect)
@@ -96,51 +90,48 @@ class UpdateEndpointGroup(forms.SelfHandlingForm):
 
 class UpdateIKEPolicy(forms.SelfHandlingForm):
     name = forms.CharField(max_length=80, label=_("Name"), required=False)
-    ikepolicy_id = forms.CharField(
-        label=_("ID"),
-        widget=forms.TextInput(attrs={'readonly': 'readonly'}))
     description = forms.CharField(
         required=False, max_length=80, label=_("Description"))
     # Currently this field has only one choice, so mark it as readonly.
-    auth_algorithm = forms.ChoiceField(
+    auth_algorithm = forms.ThemableChoiceField(
         label=_("Authorization algorithm"),
         choices=[('sha1', _('sha1'))],
-        widget=forms.ThemableSelectWidget(attrs={'readonly': 'readonly'}),
+        widget=forms.TextInput(attrs={'readonly': 'readonly'}),
         required=False)
-    encryption_algorithm = forms.ChoiceField(
+    encryption_algorithm = forms.ThemableChoiceField(
         label=_("Encryption algorithm"),
         choices=[('3des', _('3des')),
                  ('aes-128', _('aes-128')),
                  ('aes-192', _('aes-192')),
                  ('aes-256', _('aes-256'))],
         required=False)
-    ike_version = forms.ChoiceField(
+    ike_version = forms.ThemableChoiceField(
         label=_("IKE version"),
         choices=[('v1', _('v1')),
                  ('v2', _('v2'))],
         required=False)
     # Currently this field has only one choice, so mark it as readonly.
-    lifetime_units = forms.ChoiceField(
+    lifetime_units = forms.ThemableChoiceField(
         label=_("Lifetime units for IKE keys"),
         choices=[('seconds', _('seconds'))],
-        widget=forms.ThemableSelectWidget(attrs={'readonly': 'readonly'}),
+        widget=forms.TextInput(attrs={'readonly': 'readonly'}),
         required=False)
     lifetime_value = forms.IntegerField(
         min_value=60,
         label=_("Lifetime value for IKE keys"),
         help_text=_("Equal to or greater than 60"),
         required=False)
-    pfs = forms.ChoiceField(
+    pfs = forms.ThemableChoiceField(
         label=_("Perfect Forward Secrecy"),
         choices=[('group2', _('group2')),
                  ('group5', _('group5')),
                  ('group14', _('group14'))],
         required=False)
     # Currently this field has only one choice, so mark it as readonly.
-    phase1_negotiation_mode = forms.ChoiceField(
+    phase1_negotiation_mode = forms.ThemableChoiceField(
         label=_("IKE Phase1 negotiation mode"),
         choices=[('main', 'main')],
-        widget=forms.ThemableSelectWidget(attrs={'readonly': 'readonly'}),
+        widget=forms.TextInput(attrs={'readonly': 'readonly'}),
         required=False)
 
     failure_url = 'horizon:project:vpn:index'
@@ -160,38 +151,35 @@ class UpdateIKEPolicy(forms.SelfHandlingForm):
                      context['phase1_negotiation_mode'],
                      }}
             ikepolicy = api_vpn.ikepolicy_update(
-                request, context['ikepolicy_id'], **data)
-            msg = (_('IKE Policy %s was successfully updated.')
+                request, self.initial['ikepolicy_id'], **data)
+            msg = (_('IKE policy %s was successfully updated.')
                    % context['name'])
             messages.success(request, msg)
             return ikepolicy
         except Exception as e:
-            LOG.info('Failed to update IKE Policy %(id)s: %(exc)s',
-                     {'id': context['ikepolicy_id'], 'exc': e})
-            msg = _('Failed to update IKE Policy %s') % context['name']
+            LOG.info('Failed to update IKE policy %(id)s: %(exc)s',
+                     {'id': self.initial['ikepolicy_id'], 'exc': e})
+            msg = _('Failed to update IKE policy %s') % context['name']
             redirect = reverse(self.failure_url)
             exceptions.handle(request, msg, redirect=redirect)
 
 
-class UpdateIPSecPolicy(forms.SelfHandlingForm):
+class UpdateIPsecPolicy(forms.SelfHandlingForm):
     name = forms.CharField(max_length=80, label=_("Name"), required=False)
-    ipsecpolicy_id = forms.CharField(
-        label=_("ID"),
-        widget=forms.TextInput(attrs={'readonly': 'readonly'}))
     description = forms.CharField(
         required=False, max_length=80, label=_("Description"))
     # Currently this field has only one choice, so mark it as readonly.
-    auth_algorithm = forms.ChoiceField(
+    auth_algorithm = forms.ThemableChoiceField(
         label=_("Authorization algorithm"),
         choices=[('sha1', _('sha1'))],
         widget=forms.TextInput(attrs={'readonly': 'readonly'}),
         required=False)
-    encapsulation_mode = forms.ChoiceField(
+    encapsulation_mode = forms.ThemableChoiceField(
         label=_("Encapsulation mode"),
         choices=[('tunnel', _('tunnel')),
                  ('transport', _('transport'))],
         required=False)
-    encryption_algorithm = forms.ChoiceField(
+    encryption_algorithm = forms.ThemableChoiceField(
         label=_("Encryption algorithm"),
         choices=[('3des', _('3des')),
                  ('aes-128', _('aes-128')),
@@ -199,23 +187,23 @@ class UpdateIPSecPolicy(forms.SelfHandlingForm):
                  ('aes-256', _('aes-256'))],
         required=False)
     # Currently this field has only one choice, so mark it as readonly.
-    lifetime_units = forms.ChoiceField(
+    lifetime_units = forms.ThemableChoiceField(
         label=_("Lifetime units"),
         choices=[('seconds', _('seconds'))],
-        widget=forms.ThemableSelectWidget(attrs={'readonly': 'readonly'}),
+        widget=forms.TextInput(attrs={'readonly': 'readonly'}),
         required=False)
     lifetime_value = forms.IntegerField(
         min_value=60,
         label=_("Lifetime value"),
         help_text=_("Equal to or greater than 60"),
         required=False)
-    pfs = forms.ChoiceField(
+    pfs = forms.ThemableChoiceField(
         label=_("Perfect Forward Secrecy"),
         choices=[('group2', _('group2')),
                  ('group5', _('group5')),
                  ('group14', _('group14'))],
         required=False)
-    transform_protocol = forms.ChoiceField(
+    transform_protocol = forms.ThemableChoiceField(
         label=_("Transform Protocol"),
         choices=[('esp', _('esp')),
                  ('ah', _('ah')),
@@ -238,38 +226,31 @@ class UpdateIPSecPolicy(forms.SelfHandlingForm):
                      'transform_protocol': context['transform_protocol'],
                      }}
             ipsecpolicy = api_vpn.ipsecpolicy_update(
-                request, context['ipsecpolicy_id'], **data)
-            msg = (_('IPSec Policy %s was successfully updated.')
+                request, self.initial['ipsecpolicy_id'], **data)
+            msg = (_('IPsec policy %s was successfully updated.')
                    % context['name'])
             messages.success(request, msg)
             return ipsecpolicy
         except Exception as e:
-            LOG.info('Failed to update IPSec Policy %(id)s: %(exc)s',
-                     {'id': context['ipsecpolicy_id'], 'exc': e})
-            msg = _('Failed to update IPSec Policy %s') % context['name']
+            LOG.info('Failed to update IPsec policy %(id)s: %(exc)s',
+                     {'id': self.initial['ipsecpolicy_id'], 'exc': e})
+            msg = _('Failed to update IPsec policy %s') % context['name']
             redirect = reverse(self.failure_url)
             exceptions.handle(request, msg, redirect=redirect)
 
 
-class UpdateIPSecSiteConnection(forms.SelfHandlingForm):
+class UpdateIPsecSiteConnection(forms.SelfHandlingForm):
     name = forms.CharField(max_length=80, label=_("Name"), required=False)
-    ipsecsiteconnection_id = forms.CharField(
-        label=_("ID"),
-        widget=forms.TextInput(attrs={'readonly': 'readonly'}))
     description = forms.CharField(
         required=False, max_length=80, label=_("Description"))
-    peer_address = forms.IPField(
+    peer_address = forms.CharField(
         label=_("Peer gateway public IPv4/IPv6 Address or FQDN"),
         help_text=_("Peer gateway public IPv4/IPv6 address or FQDN for "
-                    "the VPN Connection"),
-        version=forms.IPv4 | forms.IPv6,
-        mask=False)
-    peer_id = forms.IPField(
+                    "the VPN Connection"),)
+    peer_id = forms.CharField(
         label=_("Peer router identity for authentication (Peer ID)"),
         help_text=_("Peer router identity for authentication. "
-                    "Can be IPv4/IPv6 address, e-mail, key ID, or FQDN"),
-        version=forms.IPv4 | forms.IPv6,
-        mask=False)
+                    "Can be IPv4/IPv6 address, e-mail, key ID, or FQDN"),)
     peer_cidrs = forms.MultiIPField(
         required=False,
         label=_("Remote peer subnet(s)"),
@@ -287,7 +268,7 @@ class UpdateIPSecSiteConnection(forms.SelfHandlingForm):
     peer_ep_group_id = forms.CharField(
         required=False,
         label=_("Peer Endpoint Group(s)"),
-        help_text=_("IPSec connection validation requires "
+        help_text=_("IPsec connection validation requires "
                     "that peer endpoints are CIDRs"))
     psk = forms.CharField(
         widget=forms.PasswordInput(render_value=True),
@@ -299,7 +280,7 @@ class UpdateIPSecSiteConnection(forms.SelfHandlingForm):
         help_text=_("Equal to or greater than 68 if the local subnet is IPv4. "
                     "Equal to or greater than 1280 if the local subnet "
                     "is IPv6."))
-    dpd_action = forms.ChoiceField(
+    dpd_action = forms.ThemableChoiceField(
         label=_("Dead peer detection actions"),
         required=False,
         choices=[('hold', _('hold')),
@@ -317,7 +298,7 @@ class UpdateIPSecSiteConnection(forms.SelfHandlingForm):
         required=False,
         label=_("Dead peer detection timeout"),
         help_text=_("Valid integer greater than the DPD interval"))
-    initiator = forms.ChoiceField(
+    initiator = forms.ThemableChoiceField(
         label=_("Initiator state"),
         required=False,
         choices=[('bi-directional', _('bi-directional')),
@@ -328,7 +309,7 @@ class UpdateIPSecSiteConnection(forms.SelfHandlingForm):
     failure_url = 'horizon:project:vpn:index'
 
     def clean(self):
-        cleaned_data = super(UpdateIPSecSiteConnection, self).clean()
+        cleaned_data = super(UpdateIPsecSiteConnection, self).clean()
         interval = cleaned_data.get('dpd_interval')
         timeout = cleaned_data.get('dpd_timeout')
 
@@ -360,16 +341,16 @@ class UpdateIPSecSiteConnection(forms.SelfHandlingForm):
                 data['peer_cidrs'] = [cidr.strip() for cidr in cidrs.split(',')
                                       if cidr.strip()]
             ipsecsiteconnection = api_vpn.ipsecsiteconnection_update(
-                request, context['ipsecsiteconnection_id'],
+                request, self.initial['ipsecsiteconnection_id'],
                 ipsec_site_connection=data)
-            msg = (_('IPSec Site Connection %s was successfully updated.')
+            msg = (_('IPsec site connection %s was successfully updated.')
                    % context['name'])
             messages.success(request, msg)
             return ipsecsiteconnection
         except Exception as e:
-            LOG.info('Failed to update IPSec Site Connection %(id)s: %(exc)s',
-                     {'id': context['ipsecsiteconnection_id'], 'exc': e})
-            msg = (_('Failed to update IPSec Site Connection %s')
+            LOG.info('Failed to update IPsec site connection %(id)s: %(exc)s',
+                     {'id': self.initial['ipsecsiteconnection_id'], 'exc': e})
+            msg = (_('Failed to update IPsec site connection %s')
                    % context['name'])
             redirect = reverse(self.failure_url)
             exceptions.handle(request, msg, redirect=redirect)
